/****************************************************************************
** Meta object code from reading C++ file 'window.h'
**
** Created: Thu May 29 14:07:49 2008
**      by: The Qt Meta Object Compiler version 59 (Qt 4.4.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "window.h"
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'window.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 59
#error "This file was generated using the moc from 4.4.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
static const uint qt_meta_data_KWD__Window[] = {

 // content:
       1,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   10, // methods
       0,    0, // properties
       0,    0, // enums/sets

 // slots: signature, parameters, type, tag, flags
      20,   13,   12,   12, 0x08,
      51,   13,   12,   12, 0x08,
      89,   13,   12,   12, 0x08,
     127,   12,   12,   12, 0x08,
     152,   12,   12,   12, 0x08,

       0        // eod
};

static const char qt_meta_stringdata_KWD__Window[] = {
    "KWD::Window\0\0action\0handlePopupActivated(QAction*)\0"
    "handleOpacityPopupActivated(QAction*)\0"
    "handleDesktopPopupActivated(QAction*)\0"
    "handlePopupAboutToShow()\0"
    "handleProcessKillerExited()\0"
};

const QMetaObject KWD::Window::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_KWD__Window,
      qt_meta_data_KWD__Window, 0 }
};

const QMetaObject *KWD::Window::metaObject() const
{
    return &staticMetaObject;
}

void *KWD::Window::qt_metacast(const char *_clname)
{
    if (!_clname) return 0;
    if (!strcmp(_clname, qt_meta_stringdata_KWD__Window))
	return static_cast<void*>(const_cast< Window*>(this));
    if (!strcmp(_clname, "KDecorationBridge"))
	return static_cast< KDecorationBridge*>(const_cast< Window*>(this));
    return QWidget::qt_metacast(_clname);
}

int KWD::Window::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: handlePopupActivated((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 1: handleOpacityPopupActivated((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 2: handleDesktopPopupActivated((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 3: handlePopupAboutToShow(); break;
        case 4: handleProcessKillerExited(); break;
        }
        _id -= 5;
    }
    return _id;
}
QT_END_MOC_NAMESPACE
